@@ -18,13 +18,13 @@ class PDFALStarColLearner(PDFALearner):
         self._teacher = None
         self.tolerance = None
 
-    def learn(self, teacher: ProbabilisticTeacher) -> LearningResult:
+    def learn(self, teacher: ProbabilisticTeacher, verbose: bool = False) -> LearningResult:
         self.terminal_symbol = teacher.terminal_symbol
         self._teacher = teacher
         self.tolerance = teacher.tolerance
         start_time = time.time()
         self.reset()
-        print("\n\n***** Learning started at:", start_time, "*****\n\n")
+        if verbose: print("\n\n***** Learning started at:", start_time, "*****\n\n")
 
         model = None
         model_learned = False
@@ -32,30 +32,31 @@ class PDFALStarColLearner(PDFALearner):
         counter_example_count = 0
 
         while not model_learned:
-            print("*** Start Iter", counter, "***")
+            if verbose: print("*** Start Iter", counter, "***")
             counter += 1
             start_inter_time = time.time()
 
-            print("Closing table...")
+            if verbose: print("Closing table...")
             self.__close()
-            print("Translating...")
+            if verbose: print("Translating...")
             model = self.model_translator.translate(self.observation_table, self.tolerance, self.terminal_symbol)
-            print("Performing Equivalence Query...")
+            if verbose: print("Performing Equivalence Query...")
             model_learned, counterexample = self.perform_equivalence_query(model)
             if not model_learned:
                 ce_time = time.time() - start_time
-                print("Found CounterExample after", ce_time, ":", counterexample)
+                if verbose: print("Found CounterExample after", ce_time, ":", counterexample)
                 counter_example_count += 1
                 self.__update_observation_table_with(counterexample)
 
             inter_time = time.time() - start_inter_time
-            print("*** Iter", counter, "finished after(secs):", inter_time, "- states:", len(model.weighted_states),
+            if verbose: print("*** Iter", counter, "finished after(secs):", inter_time, "- states:", len(model.weighted_states),
                   "- overall CE count:", counter_example_count, "***\n\n")
 
-        print("***** Learning completed successfully *****\n\n")
+        if verbose: print("***** Learning completed successfully *****\n\n")
         info = {
             'equivalence_queries_count': self._teacher.equivalence_queries_count,
-            'last_token_weight_queries_count': self._teacher.last_token_weight_queries_count,           
+            'last_token_weight_queries_count': self._teacher.last_token_weight_queries_count,     
+            'observation_table_prefixes':self.observation_table              
         }
         learningResult = LearningResult(model, len(model.weighted_states), info)
         return learningResult
@@ -109,17 +110,19 @@ class PDFALStarColLearner(PDFALearner):
                 self.__add_to_blue(new_blue_sequence)
             violating_sequence = self.observation_table.get_violating_closedness_sequence()
 
-    def _fill_hole_for(self, sequence: Sequence, suffix):
-        self.observation_table[sequence].append(self._teacher.last_token_weights(sequence, [suffix])[0])
+    def _fill_hole_for(self, sequence: Sequence, suffixes):
+        self.observation_table[sequence].extend(self._teacher.last_token_weights(sequence, suffixes))
 
     def __update_observation_table_with(self, counterexample):
+        all_suffixes = []
         for symbol in self.__symbols:
             count = counterexample + symbol
             suffixes = count.get_suffixes()
             for suffix in suffixes:
                 self.observation_table.add_suffix(suffix)
-                for sequence in self.observation_table.get_observed_sequences():
-                    self._fill_hole_for(sequence, suffix)
+                all_suffixes.append(suffix)
+        for sequence in self.observation_table.get_observed_sequences():
+            self._fill_hole_for(sequence, all_suffixes)
 
     # Helper methods
 
